@@ -1,4 +1,4 @@
-"""Type definitions
+"""Type definitions.
 
 A JSON type that would be nice if recursive types were supported:
 
@@ -15,7 +15,15 @@ A JSON type that would be nice if recursive types were supported:
     JsonType = Union[Dict[str, JsonValuesType], List[JsonValuesType]]
 """
 
-from typing import Protocol, Type, TypeVar, Union, final, runtime_checkable
+from typing import (
+    Any,
+    Protocol,
+    Type,
+    TypeVar,
+    Union,
+    final,
+    runtime_checkable,
+)
 
 # pylint: disable=too-few-public-methods
 # pylint: disable=missing-function-docstring
@@ -23,10 +31,13 @@ from typing import Protocol, Type, TypeVar, Union, final, runtime_checkable
 
 @final
 class NoResult:
-    """This value represents no result. Necessary because we care about None"""
+    """This value represents no result.
+
+    Necessary because we care about None
+    """
 
     def __new__(cls) -> Type["NoResult"]:  # type: ignore
-        """Simply returns reference to itself, making a defacto singleton"""
+        """Simply returns reference to itself, making a defacto singleton."""
         return cls
 
 
@@ -37,14 +48,14 @@ Possible = Union[_V, Type[NoResult]]  # pylint: disable=invalid-name
 T = TypeVar("T")  # pylint: disable=invalid-name
 
 
-def is_no_result(value: object) -> bool:
-    """Checks if value is NoResult"""
+def is_no_result(value: Any) -> bool:
+    """Checks if value is NoResult."""
     return value is NoResult
 
 
 @runtime_checkable
 class NamedTupleType(Protocol):
-    """NamedTuple protocol; methods only associated with namedtuples"""
+    """NamedTuple protocol; methods only associated with namedtuples."""
 
     def _make(self):
         ...
